# 命令行听机核，你值得拥有（Linux Mac）

命令行听机核，给你不一样的体验, 灵感来源于musicbox, Python3编写
支持时间轴！
[![gaycore-gif](https://github.com/yihong0618/gaycore/blob/master/img/gcore1.gif)]

## 安装

### mpg123 用于后台播放歌曲

### macos安装

  - pip3 install gaycore
  - brew install mpg123

### Linux
  - pip3 install gaycore
  - 安装 mpg123
  - **Ubuntu下** sudo apt install mpg123


## 按键说明

- 上下左右（移动， 进入下一层目录， 返回上一层目录）
- （h,j,k,l）同上 vim 方式
- q 退出
- Enter 播放电台
- Space 暂停 or 继续播放
- f 快进
- d 下载电台
- w 打开时间轴图片（或打开链接）
- o 打开时间轴来源
